@@ -54,7 +54,7 @@ class RDBService:
             fields=[]
             values=[]
             for key in data:
-                fields.append('\'' + key + '\'')
+                fields.append(key)
                 values.append(self.__toValue(data[key]))
             sql = 'insert into {} ({}) values ({})'.format(table,','.join(fields),','.join(values))
             cusor = self.conn.cursor()
